



# CHANGELOG





## v3.1.0 (2025-12-04)
## v3.1.0-rc.1 (2025-11-26)
## v3.0.0 (2025-11-20)
## v2.4.2-rc.10 (2025-11-10)
## v2.4.2-rc.9 (2025-11-06)
## v2.4.2-rc.4 (2025-10-31)
## v2.4.2-rc.3 (2025-10-31)
## v2.4.2-rc.2 (2025-10-31)
### 📖 Documentation


-  add coloc pip to docs (#1146) [\@Szymon Szyszkowski](mailto:69353402+project-defiant@users.noreply.github.com)

## v2.4.2-rc.1 (2025-09-22)
## v2.4.1 (2025-09-05)
### 📖 Documentation


-  fix typo [\@Szymon Szyszkowski](mailto:69353402+project-defiant@users.noreply.github.com)


-  update release badge and xgboost instructions [\@project-defiant](mailto:szymonszyszkowski@gmail.com)

## v2.4.0 (2025-09-02)
## v2.4.0-rc.4 (2025-08-18)
## v2.4.0-rc.3 (2025-07-30)
## v2.4.0-rc.2 (2025-07-21)
## v2.3.0 (2025-07-15)
## v2.3.0-rc.9 (2025-06-11)
## v2.3.0-rc.8 (2025-06-09)
## v2.3.0-rc.5 (2025-06-06)
## v2.3.0-rc.3 (2025-05-21)
### 📖 Documentation


-  remove roadmap section (#1042) [\@David Ochoa](mailto:ochoa@ebi.ac.uk)

## v2.3.0-rc.1 (2025-03-17)
## v2.2.0 (2025-03-10)
## v2.2.0-rc.6 (2025-03-06)
## v2.2.0-rc.5 (2025-02-26)
## v2.2.0-rc.4 (2025-02-20)
## v2.2.0-rc.3 (2025-02-19)
## v2.2.0-rc.2 (2025-02-07)
## v2.1.0 (2025-02-06)
## v2.0.2-rc.4 (2025-02-06)
## v2.0.2-rc.3 (2025-02-03)
## v2.0.2-rc.2 (2025-01-28)
## v2.0.1 (2024-12-17)
## v2.0.0 (2024-12-10)
## v2.0.0-rc.3 (2024-11-27)
## v2.0.0-rc.2 (2024-11-26)
## v2.0.0-rc.1 (2024-11-22)
### 📖 Documentation


-  fix broken refs (#768) [\@David Ochoa](mailto:ochoa@ebi.ac.uk)


-  macos fix for some functions (#729) [\@Daniel-Considine](mailto:113430683+Daniel-Considine@users.noreply.github.com)

## v1.7.0 (2024-07-22)
## v1.6.0 (2024-07-16)
## v1.5.0 (2024-07-14)
## v1.4.0 (2024-07-12)
## v1.3.0 (2024-05-17)
## v1.2.0 (2024-03-07)
## v1.1.1 (2024-02-22)
### 📖 Documentation


-  susie inf method reloacated with the rest of the methods [\@David Ochoa](mailto:dogcaesar@gmail.com)

## v1.1.0 (2024-02-08)
### 📖 Documentation


- \[**StudyLocusQualityCheck**\] update outdated attributes (#452) [\@David Ochoa](mailto:ochoa@ebi.ac.uk)


-  add gentropy first steps guide (#449) [\@Irene López](mailto:45119610+ireneisdoomed@users.noreply.github.com)


-  pypi badges (#439) [\@David Ochoa](mailto:ochoa@ebi.ac.uk)

## v1.0.0 (2024-01-18)
### 📖 Documentation


-  fix step name (#438) [\@David Ochoa](mailto:ochoa@ebi.ac.uk)


-  docs ammendments (#437) [\@David Ochoa](mailto:ochoa@ebi.ac.uk)


-  several enhancements on docs including index and installation (#433) [\@David Ochoa](mailto:ochoa@ebi.ac.uk)


-  release documentation preparation (#432) [\@Yakov](mailto:yt4@sanger.ac.uk)


-  update index.md [\@David Ochoa](mailto:ochoa@ebi.ac.uk)


-  update README.md (#431) [\@David Ochoa](mailto:ochoa@ebi.ac.uk)


-  gentropy hero image (#430) [\@David Ochoa](mailto:ochoa@ebi.ac.uk)


-  documentation link (#429) [\@David Ochoa](mailto:ochoa@ebi.ac.uk)


-  corrected and added documentation to datasource (#362) [\@Yakov](mailto:yt4@sanger.ac.uk)

## v0.0.0-rc.1 (2023-12-14)
### 📖 Documentation


-  finngen description v1 (#345) [\@Yakov](mailto:yt4@sanger.ac.uk)


-  minify plugin removed to prevent clash in local development (#284) [\@David Ochoa](mailto:ochoa@ebi.ac.uk)


-  add automatically generated docs [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  update contributing checklist [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  update running instructions [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  pics step [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  generalizing GnomAD class documentation [\@Daniel Suveges](mailto:daniel.suveges@protonmail.com)


-  add rudimentary documentation on DAGs and autoscaling [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  rewrite section to add user ID [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  remove unnecessary comment which is replaced by a note [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  set correct user ID to fix file access issues [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  clarify parameter specific for CeleryExecutor [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  do not hardcode name of project [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  fix list and code block formatting [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  fix contributing checklist formatting [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  streamline Airflow documentation style and tone [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  l2g step title [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  add session to attributes list for all steps [\@Irene López](mailto:irene.lopezs@protonmail.com)


- \[**l2g**\] add step documentation [\@Irene López](mailto:irene.lopezs@protonmail.com)


- \[**l2g**\] add titles to files [\@Irene López](mailto:irene.lopezs@protonmail.com)


-  study_locus schema at the end [\@Irene López](mailto:irene.lopezs@protonmail.com)


-  create and organise development section [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  update index to match docs update [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  fix command to start docs server [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  make development a separate section [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  add instructions for running Airflow [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  create and organise development section [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  structural changes and data source images [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  rename all instances of Thurnman to Thurman [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  several fixes in docstrings [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  window_length no longer defines the collect locus [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  enhance locus_collect column [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  more meaningful message [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  added descriptions [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  remove links pointing nowhere to fix mkdocs [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  fix incorrect reference [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  fix relative link in `contributing.md` [\@Irene López](mailto:irene.lopezs@protonmail.com)


-  improve overlaps docs [\@Irene López](mailto:irene.lopezs@protonmail.com)


-  improve documentation on the overall process [\@Irene López](mailto:irene.lopezs@protonmail.com)


-  page for window based clumping [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  remove the now unneeded file from utils [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  reorganise troubleshooting section [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  update index with a separate troubleshooting section [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  move troubleshooting information from the contributing guide [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  update documentation on building and testing [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  improve `_annotate_discovery_sample_sizes` docs [\@Irene López](mailto:irene.lopezs@protonmail.com)


-  updated java version text [\@hlnicholls](mailto:53306752+hlnicholls@users.noreply.github.com)


-  compile the new contributing section [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  add contributing information to index [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  move technical information out of README [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  Update ukbiobank.py docstring [\@hlnicholls](mailto:53306752+hlnicholls@users.noreply.github.com)


-  add need to install java version 8 [\@hlnicholls](mailto:53306752+hlnicholls@users.noreply.github.com)


-  finngen study index dataset duplicated in docs [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  finngen study index dataset duplicated in docs [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  fix link [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  update index.md [\@buniello](mailto:30833755+buniello@users.noreply.github.com)


-  fix fixes [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  reference renamed to components based on buniellos request [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  correct version naming example [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  amend documentation to make clear how versioning works [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  missing docs for finger step added [\@David Ochoa](mailto:ochoa@ebi.ac.uk)


-  rewrite README with running instructions [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  add documentation on StudyIndexFinnGen [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  add troubleshooting instructions for Pyenv/Poetry [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  simplify instructions for development environment [\@Kirill Tsukanov](mailto:tsukanoffkirill@gmail.com)


-  docs badge added [\@David Ochoa](mailto:ochoa@ebi.ac.uk)


-  fixing actions [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  fixing actions [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  fixing actions [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  fix to prevent docs crashing [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  fix doc [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  explanation improved [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  missing docstring [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  gwas catalog step [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  missing ld clumped [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  typo [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  including titles in pages [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  added docs [\@Irene López](mailto:irene.lopezs@protonmail.com)


-  improved description [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  extra help to understand current configs [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  address david comment on verbose docs [\@Irene López](mailto:irene.lopezs@protonmail.com)


-  correct reference to coloc modules [\@Irene López](mailto:irene.lopezs@protonmail.com)


-  update summary of logic [\@Irene López](mailto:irene.lopezs@protonmail.com)


-  added v2g docs page [\@Irene López](mailto:irene.lopezs@protonmail.com)


-  scafolding required for variant docs [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  generate_variant_annotation documentation [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  removing old docsc (#36) [\@David Ochoa](mailto:ochoa@ebi.ac.uk)


-  rounding numbers for safety [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  first pyspark function example [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  non-spark function doctest [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  doctest functionality added [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  openblas and lapack libraries required for scipy [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  improvements on index page and roadmap [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  license added [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  better docs for mkdocs [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  function docstring [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  schema functions description [\@David Ochoa](mailto:dogcaesar@gmail.com)


-  adding badges to README [\@Daniel Suveges](mailto:daniel.suveges@protonmail.com)


-  adding badges to README [\@Daniel Suveges](mailto:daniel.suveges@protonmail.com)


-  adding documenation for gwas ingestion [\@Daniel Suveges](mailto:daniel.suveges@protonmail.com)


-  not necessary [\@David Ochoa](mailto:ochoa@ebi.ac.uk)


-  adding documentation for Intervals and Variant annotation [\@Daniel Suveges](mailto:daniel.suveges@protonmail.com)
